@@ -1,35 +1,43 @@
 package DBIx::Class::Helper::ResultSet;
-{
-  $DBIx::Class::Helper::ResultSet::VERSION = '2.017000';
-}
 
 use parent qw{
+   DBIx::Class::Helper::ResultSet::AutoRemoveColumns
+   DBIx::Class::Helper::ResultSet::CorrelateRelationship
    DBIx::Class::Helper::ResultSet::IgnoreWantarray
+   DBIx::Class::Helper::ResultSet::Me
+   DBIx::Class::Helper::ResultSet::NoColumns
    DBIx::Class::Helper::ResultSet::Random
-   DBIx::Class::Helper::ResultSet::Union
-   DBIx::Class::Helper::ResultSet::VirtualView
+   DBIx::Class::Helper::ResultSet::RemoveColumns
+   DBIx::Class::Helper::ResultSet::ResultClassDWIM
+   DBIx::Class::Helper::ResultSet::SearchOr
+   DBIx::Class::Helper::ResultSet::SetOperations
+   DBIx::Class::Helper::ResultSet::Shortcut
 };
 
 # ABSTRACT: All the ResultSet Helpers in one place
 
+our $VERSION = '2.019002'; # VERSION
+
 1;
 
 __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 DBIx::Class::Helper::ResultSet - All the ResultSet Helpers in one place
 
 =head1 VERSION
 
-version 2.017000
+version 2.019002
 
 =head1 DESCRIPTION
 
 This is just a simple Helper helper that includes all of the ResultSet Helpers
-in one convenient module.
+in one convenient module.  It does not include deprecated helpers.
 
 =head2 NOTE
 
@@ -65,7 +73,7 @@ Arthur Axel "fREW" Schmidt <frioux+cpan@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Arthur Axel "fREW" Schmidt.
+This software is copyright (c) 2014 by Arthur Axel "fREW" Schmidt.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
