@@ -1,13 +1,12 @@
 package DBIx::Class::Helper::ResultSet::CorrelateRelationship;
-{
-  $DBIx::Class::Helper::ResultSet::CorrelateRelationship::VERSION = '2.017000';
-}
 
 use strict;
 use warnings;
 
 # ABSTRACT: Easily correlate your ResultSets
 
+our $VERSION = '2.019002'; # VERSION
+
 sub correlate {
    my ($self, $rel) = @_;
 
@@ -31,13 +30,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 DBIx::Class::Helper::ResultSet::CorrelateRelationship - Easily correlate your ResultSets
 
 =head1 VERSION
 
-version 2.017000
+version 2.019002
 
 =head1 SYNOPSIS
 
@@ -52,7 +53,7 @@ version 2.017000
 
    $self->search(undef, {
      '+columns' => {
-       book_count => $self->correlate('book')->count_rs->as_query
+       book_count => $self->correlate('books')->count_rs->as_query
      }
    });
  }
@@ -209,7 +210,7 @@ Arthur Axel "fREW" Schmidt <frioux+cpan@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Arthur Axel "fREW" Schmidt.
+This software is copyright (c) 2014 by Arthur Axel "fREW" Schmidt.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
