@@ -1,13 +1,12 @@
 package DBIx::Class::Helper::ResultSet::SetOperations;
-{
-  $DBIx::Class::Helper::ResultSet::SetOperations::VERSION = '2.013002';
-}
 
 use strict;
 use warnings;
 
 # ABSTRACT: Do set operations with DBIx::Class
 
+our $VERSION = '2.019002'; # VERSION
+
 # cribbed from perlfaq4
 sub _compare_arrays {
    my ($self, $first, $second) = @_;
@@ -71,12 +70,11 @@ sub _set_operation {
       $self->throw_exception('ResultSets do not all have the same selected columns!')
          unless $self->_compare_arrays($as, $attrs->{as});
 
-      my ($sql, $bind) = $self->result_source->storage->_select_args_to_query(
-         $attrs->{from}, $attrs->{select}, $attrs->{where}, $attrs
-      );
+      my ($sql, @bind) = @{${$_->as_query}};
+      $sql =~ s/^\s*\((.*)\)\s*$/$1/;
 
       push @sql, $sql;
-      push @params, @{$bind};
+      push @params, @bind;
    }
 
    my $query = q<(> . join(" $operation ", @sql). q<)>;
@@ -96,17 +94,19 @@ sub _set_operation {
 
 1;
 
-
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 DBIx::Class::Helper::ResultSet::SetOperations - Do set operations with DBIx::Class
 
 =head1 VERSION
 
-version 2.013002
+version 2.019002
 
 =head1 SYNOPSIS
 
@@ -198,10 +198,9 @@ Arthur Axel "fREW" Schmidt <frioux+cpan@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Arthur Axel "fREW" Schmidt.
+This software is copyright (c) 2014 by Arthur Axel "fREW" Schmidt.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
