@@ -1,35 +1,39 @@
 package DBIx::Class::Helper::Row::SelfResultSet;
-{
-  $DBIx::Class::Helper::Row::SelfResultSet::VERSION = '2.013002';
-}
 
 use strict;
 use warnings;
 
 # ABSTRACT: Easily use ResultSet methods for the current row
 
+our $VERSION = '2.019002'; # VERSION
+
 sub self_rs {
    my ($self) = @_;
 
    my $src = $self->result_source;
-   return $src->resultset->search({
-      map { $_ => $self->get_column($_) } $src->primary_columns
+   my $rs = $src->resultset;
+   my $me = $rs->current_source_alias;
+   return $rs->search({
+          # perl, sometimes I hate your guts
+      map +( "$me.$_" => $self->get_column($_) ), $src->primary_columns
    })
 }
 
 1;
 
-
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 DBIx::Class::Helper::Row::SelfResultSet - Easily use ResultSet methods for the current row
 
 =head1 VERSION
 
-version 2.013002
+version 2.019002
 
 =head1 SYNOPSIS
 
@@ -62,10 +66,9 @@ Arthur Axel "fREW" Schmidt <frioux+cpan@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Arthur Axel "fREW" Schmidt.
+This software is copyright (c) 2014 by Arthur Axel "fREW" Schmidt.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
